__rust_drop_panic

Function __rust_drop_panic 

fn __rust_drop_panic() -> !
This function is called by the panic runtime if FFI code catches a Rust panic but doesn’t rethrow it. We don’t support this case since it messes with our panic count.